# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class UserLibraryServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_users_by_userid_favoriteitems_by_id(self, user_id, id, **kwargs):  # noqa: E501
        """Unmarks an item as a favorite  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_userid_favoriteitems_by_id(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_users_by_userid_favoriteitems_by_id_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_users_by_userid_favoriteitems_by_id_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def delete_users_by_userid_favoriteitems_by_id_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Unmarks an item as a favorite  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_userid_favoriteitems_by_id_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_users_by_userid_favoriteitems_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `delete_users_by_userid_favoriteitems_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_users_by_userid_favoriteitems_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/FavoriteItems/{Id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserItemDataDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_users_by_userid_items_by_id_rating(self, user_id, id, **kwargs):  # noqa: E501
        """Deletes a user's saved personal rating for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_userid_items_by_id_rating(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_users_by_userid_items_by_id_rating_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_users_by_userid_items_by_id_rating_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def delete_users_by_userid_items_by_id_rating_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Deletes a user's saved personal rating for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_users_by_userid_items_by_id_rating_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_users_by_userid_items_by_id_rating" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `delete_users_by_userid_items_by_id_rating`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_users_by_userid_items_by_id_rating`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}/Rating', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserItemDataDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_programs_by_id(self, id, **kwargs):  # noqa: E501
        """Gets a live tv program  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_programs_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_programs_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_programs_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_livetv_programs_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live tv program  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_programs_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_programs_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_programs_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/Programs/{Id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_userid_items_by_id(self, user_id, id, **kwargs):  # noqa: E501
        """Gets an item from a user's library  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_userid_items_by_id_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_userid_items_by_id_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def get_users_by_userid_items_by_id_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Gets an item from a user's library  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_userid_items_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_users_by_userid_items_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_users_by_userid_items_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_userid_items_by_id_intros(self, user_id, id, **kwargs):  # noqa: E501
        """Gets intros to play before the main media item plays  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id_intros(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_userid_items_by_id_intros_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_userid_items_by_id_intros_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def get_users_by_userid_items_by_id_intros_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Gets intros to play before the main media item plays  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id_intros_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id', 'fields', 'enable_images', 'image_type_limit', 'enable_image_types', 'enable_user_data']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_userid_items_by_id_intros" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_users_by_userid_items_by_id_intros`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_users_by_userid_items_by_id_intros`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}/Intros', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultBaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_userid_items_by_id_localtrailers(self, user_id, id, **kwargs):  # noqa: E501
        """Gets local trailers for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id_localtrailers(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: list[BaseItemDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_userid_items_by_id_localtrailers_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_userid_items_by_id_localtrailers_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def get_users_by_userid_items_by_id_localtrailers_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Gets local trailers for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id_localtrailers_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: list[BaseItemDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id', 'fields', 'enable_images', 'image_type_limit', 'enable_image_types', 'enable_user_data']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_userid_items_by_id_localtrailers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_users_by_userid_items_by_id_localtrailers`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_users_by_userid_items_by_id_localtrailers`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}/LocalTrailers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BaseItemDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_userid_items_by_id_specialfeatures(self, user_id, id, **kwargs):  # noqa: E501
        """Gets special features for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id_specialfeatures(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Movie Id (required)
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: list[BaseItemDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_userid_items_by_id_specialfeatures_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_userid_items_by_id_specialfeatures_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def get_users_by_userid_items_by_id_specialfeatures_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Gets special features for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_by_id_specialfeatures_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Movie Id (required)
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: list[BaseItemDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id', 'fields', 'enable_images', 'image_type_limit', 'enable_image_types', 'enable_user_data']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_userid_items_by_id_specialfeatures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_users_by_userid_items_by_id_specialfeatures`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_users_by_userid_items_by_id_specialfeatures`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}/SpecialFeatures', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BaseItemDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_userid_items_latest(self, user_id, **kwargs):  # noqa: E501
        """Gets latest media  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_latest(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param int limit: Limit
        :param str parent_id: Specify this to localize the search to a specific item or folder. Omit to use the root
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, SortName, Studios, Taglines
        :param str include_item_types: Optional. If specified, results will be filtered based on item type. This allows multiple, comma delimeted.
        :param str media_types: Optional filter by MediaType. Allows multiple, comma delimited.
        :param bool is_folder: Filter by items that are folders, or not.
        :param bool is_played: Filter by items that are played, or not.
        :param bool group_items: Whether or not to group items into a parent container.
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: list[BaseItemDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_userid_items_latest_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_userid_items_latest_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_users_by_userid_items_latest_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Gets latest media  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_latest_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param int limit: Limit
        :param str parent_id: Specify this to localize the search to a specific item or folder. Omit to use the root
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, SortName, Studios, Taglines
        :param str include_item_types: Optional. If specified, results will be filtered based on item type. This allows multiple, comma delimeted.
        :param str media_types: Optional filter by MediaType. Allows multiple, comma delimited.
        :param bool is_folder: Filter by items that are folders, or not.
        :param bool is_played: Filter by items that are played, or not.
        :param bool group_items: Whether or not to group items into a parent container.
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: list[BaseItemDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'limit', 'parent_id', 'fields', 'include_item_types', 'media_types', 'is_folder', 'is_played', 'group_items', 'enable_images', 'image_type_limit', 'enable_image_types', 'enable_user_data']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_userid_items_latest" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_users_by_userid_items_latest`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501
        if 'parent_id' in params:
            query_params.append(('ParentId', params['parent_id']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'include_item_types' in params:
            query_params.append(('IncludeItemTypes', params['include_item_types']))  # noqa: E501
        if 'media_types' in params:
            query_params.append(('MediaTypes', params['media_types']))  # noqa: E501
        if 'is_folder' in params:
            query_params.append(('IsFolder', params['is_folder']))  # noqa: E501
        if 'is_played' in params:
            query_params.append(('IsPlayed', params['is_played']))  # noqa: E501
        if 'group_items' in params:
            query_params.append(('GroupItems', params['group_items']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/Latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BaseItemDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users_by_userid_items_root(self, user_id, **kwargs):  # noqa: E501
        """Gets the root folder from a user's library  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_root(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_by_userid_items_root_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_users_by_userid_items_root_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_users_by_userid_items_root_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Gets the root folder from a user's library  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_by_userid_items_root_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_by_userid_items_root" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_users_by_userid_items_root`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/Root', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_videos_by_id_additionalparts(self, id, **kwargs):  # noqa: E501
        """Gets additional parts for a video.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_videos_by_id_additionalparts(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :param str user_id: Optional. Filter by user id, and attach user data
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_videos_by_id_additionalparts_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_videos_by_id_additionalparts_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_videos_by_id_additionalparts_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets additional parts for a video.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_videos_by_id_additionalparts_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :param str user_id: Optional. Filter by user id, and attach user data
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines, TrailerUrls
        :param bool enable_images: Optional, include image information in output
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param bool enable_user_data: Optional, include user data
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'user_id', 'fields', 'enable_images', 'image_type_limit', 'enable_image_types', 'enable_user_data']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_videos_by_id_additionalparts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_videos_by_id_additionalparts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Videos/{Id}/AdditionalParts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultBaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_access(self, body, **kwargs):  # noqa: E501
        """Updates user item access  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_access(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserLibraryUpdateUserItemAccess body: UpdateUserItemAccess (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_access_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_access_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_access_with_http_info(self, body, **kwargs):  # noqa: E501
        """Updates user item access  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_access_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserLibraryUpdateUserItemAccess body: UpdateUserItemAccess (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_access" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_access`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/Access', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_by_id_makeprivate(self, id, **kwargs):  # noqa: E501
        """Makes an item private  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_by_id_makeprivate(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_by_id_makeprivate_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_by_id_makeprivate_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_items_by_id_makeprivate_with_http_info(self, id, **kwargs):  # noqa: E501
        """Makes an item private  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_by_id_makeprivate_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_by_id_makeprivate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_items_by_id_makeprivate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/{Id}/MakePrivate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_by_id_makepublic(self, id, **kwargs):  # noqa: E501
        """Makes an item public to all users  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_by_id_makepublic(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_by_id_makepublic_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_by_id_makepublic_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_items_by_id_makepublic_with_http_info(self, id, **kwargs):  # noqa: E501
        """Makes an item public to all users  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_by_id_makepublic_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_by_id_makepublic" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_items_by_id_makepublic`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/{Id}/MakePublic', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_shared_leave(self, body, **kwargs):  # noqa: E501
        """Leaves a shared item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_shared_leave(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserLibraryLeaveSharedItems body: LeaveSharedItems (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_shared_leave_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_shared_leave_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_shared_leave_with_http_info(self, body, **kwargs):  # noqa: E501
        """Leaves a shared item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_shared_leave_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserLibraryLeaveSharedItems body: LeaveSharedItems (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_shared_leave" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_shared_leave`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/Shared/Leave', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_userid_favoriteitems_by_id(self, user_id, id, **kwargs):  # noqa: E501
        """Marks an item as a favorite  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_favoriteitems_by_id(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_userid_favoriteitems_by_id_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_userid_favoriteitems_by_id_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_userid_favoriteitems_by_id_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Marks an item as a favorite  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_favoriteitems_by_id_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_userid_favoriteitems_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_users_by_userid_favoriteitems_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_userid_favoriteitems_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/FavoriteItems/{Id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserItemDataDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_userid_favoriteitems_by_id_delete(self, user_id, id, **kwargs):  # noqa: E501
        """Unmarks an item as a favorite  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_favoriteitems_by_id_delete(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_userid_favoriteitems_by_id_delete_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_userid_favoriteitems_by_id_delete_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_userid_favoriteitems_by_id_delete_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Unmarks an item as a favorite  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_favoriteitems_by_id_delete_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_userid_favoriteitems_by_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_users_by_userid_favoriteitems_by_id_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_userid_favoriteitems_by_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/FavoriteItems/{Id}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserItemDataDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_userid_items_by_id_hidefromresume(self, user_id, id, hide, **kwargs):  # noqa: E501
        """Updates a user's hide from resume for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_items_by_id_hidefromresume(user_id, id, hide, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param bool hide: Whether the item should be hidden from reusme or not. true/false (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_userid_items_by_id_hidefromresume_with_http_info(user_id, id, hide, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_userid_items_by_id_hidefromresume_with_http_info(user_id, id, hide, **kwargs)  # noqa: E501
            return data

    def post_users_by_userid_items_by_id_hidefromresume_with_http_info(self, user_id, id, hide, **kwargs):  # noqa: E501
        """Updates a user's hide from resume for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_items_by_id_hidefromresume_with_http_info(user_id, id, hide, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param bool hide: Whether the item should be hidden from reusme or not. true/false (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id', 'hide']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_userid_items_by_id_hidefromresume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_users_by_userid_items_by_id_hidefromresume`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_userid_items_by_id_hidefromresume`")  # noqa: E501
        # verify the required parameter 'hide' is set
        if ('hide' not in params or
                params['hide'] is None):
            raise ValueError("Missing the required parameter `hide` when calling `post_users_by_userid_items_by_id_hidefromresume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'hide' in params:
            query_params.append(('Hide', params['hide']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}/HideFromResume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserItemDataDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_userid_items_by_id_rating(self, user_id, id, likes, **kwargs):  # noqa: E501
        """Updates a user's rating for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_items_by_id_rating(user_id, id, likes, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param bool likes: Whether the user likes the item or not. true/false (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_userid_items_by_id_rating_with_http_info(user_id, id, likes, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_userid_items_by_id_rating_with_http_info(user_id, id, likes, **kwargs)  # noqa: E501
            return data

    def post_users_by_userid_items_by_id_rating_with_http_info(self, user_id, id, likes, **kwargs):  # noqa: E501
        """Updates a user's rating for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_items_by_id_rating_with_http_info(user_id, id, likes, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :param bool likes: Whether the user likes the item or not. true/false (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id', 'likes']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_userid_items_by_id_rating" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_users_by_userid_items_by_id_rating`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_userid_items_by_id_rating`")  # noqa: E501
        # verify the required parameter 'likes' is set
        if ('likes' not in params or
                params['likes'] is None):
            raise ValueError("Missing the required parameter `likes` when calling `post_users_by_userid_items_by_id_rating`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'likes' in params:
            query_params.append(('Likes', params['likes']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}/Rating', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserItemDataDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_users_by_userid_items_by_id_rating_delete(self, user_id, id, **kwargs):  # noqa: E501
        """Deletes a user's saved personal rating for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_items_by_id_rating_delete(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_users_by_userid_items_by_id_rating_delete_with_http_info(user_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_users_by_userid_items_by_id_rating_delete_with_http_info(user_id, id, **kwargs)  # noqa: E501
            return data

    def post_users_by_userid_items_by_id_rating_delete_with_http_info(self, user_id, id, **kwargs):  # noqa: E501
        """Deletes a user's saved personal rating for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_users_by_userid_items_by_id_rating_delete_with_http_info(user_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: User Id (required)
        :param str id: Item Id (required)
        :return: UserItemDataDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_by_userid_items_by_id_rating_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `post_users_by_userid_items_by_id_rating_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_users_by_userid_items_by_id_rating_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['UserId'] = params['user_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Users/{UserId}/Items/{Id}/Rating/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserItemDataDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class DeviceProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'supported_media_types': 'str',
        'max_streaming_bitrate': 'int',
        'music_streaming_transcoding_bitrate': 'int',
        'max_static_music_bitrate': 'int',
        'direct_play_profiles': 'list[DirectPlayProfile]',
        'transcoding_profiles': 'list[TranscodingProfile]',
        'container_profiles': 'list[ContainerProfile]',
        'codec_profiles': 'list[CodecProfile]',
        'response_profiles': 'list[ResponseProfile]',
        'subtitle_profiles': 'list[SubtitleProfile]'
    }

    attribute_map = {
        'name': 'Name',
        'id': 'Id',
        'supported_media_types': 'SupportedMediaTypes',
        'max_streaming_bitrate': 'MaxStreamingBitrate',
        'music_streaming_transcoding_bitrate': 'MusicStreamingTranscodingBitrate',
        'max_static_music_bitrate': 'MaxStaticMusicBitrate',
        'direct_play_profiles': 'DirectPlayProfiles',
        'transcoding_profiles': 'TranscodingProfiles',
        'container_profiles': 'ContainerProfiles',
        'codec_profiles': 'CodecProfiles',
        'response_profiles': 'ResponseProfiles',
        'subtitle_profiles': 'SubtitleProfiles'
    }

    def __init__(self, name=None, id=None, supported_media_types=None, max_streaming_bitrate=None, music_streaming_transcoding_bitrate=None, max_static_music_bitrate=None, direct_play_profiles=None, transcoding_profiles=None, container_profiles=None, codec_profiles=None, response_profiles=None, subtitle_profiles=None):  # noqa: E501
        """DeviceProfile - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._id = None
        self._supported_media_types = None
        self._max_streaming_bitrate = None
        self._music_streaming_transcoding_bitrate = None
        self._max_static_music_bitrate = None
        self._direct_play_profiles = None
        self._transcoding_profiles = None
        self._container_profiles = None
        self._codec_profiles = None
        self._response_profiles = None
        self._subtitle_profiles = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if supported_media_types is not None:
            self.supported_media_types = supported_media_types
        if max_streaming_bitrate is not None:
            self.max_streaming_bitrate = max_streaming_bitrate
        if music_streaming_transcoding_bitrate is not None:
            self.music_streaming_transcoding_bitrate = music_streaming_transcoding_bitrate
        if max_static_music_bitrate is not None:
            self.max_static_music_bitrate = max_static_music_bitrate
        if direct_play_profiles is not None:
            self.direct_play_profiles = direct_play_profiles
        if transcoding_profiles is not None:
            self.transcoding_profiles = transcoding_profiles
        if container_profiles is not None:
            self.container_profiles = container_profiles
        if codec_profiles is not None:
            self.codec_profiles = codec_profiles
        if response_profiles is not None:
            self.response_profiles = response_profiles
        if subtitle_profiles is not None:
            self.subtitle_profiles = subtitle_profiles

    @property
    def name(self):
        """Gets the name of this DeviceProfile.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this DeviceProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeviceProfile.

        The name.  # noqa: E501

        :param name: The name of this DeviceProfile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this DeviceProfile.  # noqa: E501


        :return: The id of this DeviceProfile.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceProfile.


        :param id: The id of this DeviceProfile.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def supported_media_types(self):
        """Gets the supported_media_types of this DeviceProfile.  # noqa: E501


        :return: The supported_media_types of this DeviceProfile.  # noqa: E501
        :rtype: str
        """
        return self._supported_media_types

    @supported_media_types.setter
    def supported_media_types(self, supported_media_types):
        """Sets the supported_media_types of this DeviceProfile.


        :param supported_media_types: The supported_media_types of this DeviceProfile.  # noqa: E501
        :type: str
        """

        self._supported_media_types = supported_media_types

    @property
    def max_streaming_bitrate(self):
        """Gets the max_streaming_bitrate of this DeviceProfile.  # noqa: E501


        :return: The max_streaming_bitrate of this DeviceProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_streaming_bitrate

    @max_streaming_bitrate.setter
    def max_streaming_bitrate(self, max_streaming_bitrate):
        """Sets the max_streaming_bitrate of this DeviceProfile.


        :param max_streaming_bitrate: The max_streaming_bitrate of this DeviceProfile.  # noqa: E501
        :type: int
        """

        self._max_streaming_bitrate = max_streaming_bitrate

    @property
    def music_streaming_transcoding_bitrate(self):
        """Gets the music_streaming_transcoding_bitrate of this DeviceProfile.  # noqa: E501


        :return: The music_streaming_transcoding_bitrate of this DeviceProfile.  # noqa: E501
        :rtype: int
        """
        return self._music_streaming_transcoding_bitrate

    @music_streaming_transcoding_bitrate.setter
    def music_streaming_transcoding_bitrate(self, music_streaming_transcoding_bitrate):
        """Sets the music_streaming_transcoding_bitrate of this DeviceProfile.


        :param music_streaming_transcoding_bitrate: The music_streaming_transcoding_bitrate of this DeviceProfile.  # noqa: E501
        :type: int
        """

        self._music_streaming_transcoding_bitrate = music_streaming_transcoding_bitrate

    @property
    def max_static_music_bitrate(self):
        """Gets the max_static_music_bitrate of this DeviceProfile.  # noqa: E501


        :return: The max_static_music_bitrate of this DeviceProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_static_music_bitrate

    @max_static_music_bitrate.setter
    def max_static_music_bitrate(self, max_static_music_bitrate):
        """Sets the max_static_music_bitrate of this DeviceProfile.


        :param max_static_music_bitrate: The max_static_music_bitrate of this DeviceProfile.  # noqa: E501
        :type: int
        """

        self._max_static_music_bitrate = max_static_music_bitrate

    @property
    def direct_play_profiles(self):
        """Gets the direct_play_profiles of this DeviceProfile.  # noqa: E501

        The direct play profiles.  # noqa: E501

        :return: The direct_play_profiles of this DeviceProfile.  # noqa: E501
        :rtype: list[DirectPlayProfile]
        """
        return self._direct_play_profiles

    @direct_play_profiles.setter
    def direct_play_profiles(self, direct_play_profiles):
        """Sets the direct_play_profiles of this DeviceProfile.

        The direct play profiles.  # noqa: E501

        :param direct_play_profiles: The direct_play_profiles of this DeviceProfile.  # noqa: E501
        :type: list[DirectPlayProfile]
        """

        self._direct_play_profiles = direct_play_profiles

    @property
    def transcoding_profiles(self):
        """Gets the transcoding_profiles of this DeviceProfile.  # noqa: E501

        The transcoding profiles.  # noqa: E501

        :return: The transcoding_profiles of this DeviceProfile.  # noqa: E501
        :rtype: list[TranscodingProfile]
        """
        return self._transcoding_profiles

    @transcoding_profiles.setter
    def transcoding_profiles(self, transcoding_profiles):
        """Sets the transcoding_profiles of this DeviceProfile.

        The transcoding profiles.  # noqa: E501

        :param transcoding_profiles: The transcoding_profiles of this DeviceProfile.  # noqa: E501
        :type: list[TranscodingProfile]
        """

        self._transcoding_profiles = transcoding_profiles

    @property
    def container_profiles(self):
        """Gets the container_profiles of this DeviceProfile.  # noqa: E501


        :return: The container_profiles of this DeviceProfile.  # noqa: E501
        :rtype: list[ContainerProfile]
        """
        return self._container_profiles

    @container_profiles.setter
    def container_profiles(self, container_profiles):
        """Sets the container_profiles of this DeviceProfile.


        :param container_profiles: The container_profiles of this DeviceProfile.  # noqa: E501
        :type: list[ContainerProfile]
        """

        self._container_profiles = container_profiles

    @property
    def codec_profiles(self):
        """Gets the codec_profiles of this DeviceProfile.  # noqa: E501


        :return: The codec_profiles of this DeviceProfile.  # noqa: E501
        :rtype: list[CodecProfile]
        """
        return self._codec_profiles

    @codec_profiles.setter
    def codec_profiles(self, codec_profiles):
        """Sets the codec_profiles of this DeviceProfile.


        :param codec_profiles: The codec_profiles of this DeviceProfile.  # noqa: E501
        :type: list[CodecProfile]
        """

        self._codec_profiles = codec_profiles

    @property
    def response_profiles(self):
        """Gets the response_profiles of this DeviceProfile.  # noqa: E501


        :return: The response_profiles of this DeviceProfile.  # noqa: E501
        :rtype: list[ResponseProfile]
        """
        return self._response_profiles

    @response_profiles.setter
    def response_profiles(self, response_profiles):
        """Sets the response_profiles of this DeviceProfile.


        :param response_profiles: The response_profiles of this DeviceProfile.  # noqa: E501
        :type: list[ResponseProfile]
        """

        self._response_profiles = response_profiles

    @property
    def subtitle_profiles(self):
        """Gets the subtitle_profiles of this DeviceProfile.  # noqa: E501


        :return: The subtitle_profiles of this DeviceProfile.  # noqa: E501
        :rtype: list[SubtitleProfile]
        """
        return self._subtitle_profiles

    @subtitle_profiles.setter
    def subtitle_profiles(self, subtitle_profiles):
        """Sets the subtitle_profiles of this DeviceProfile.


        :param subtitle_profiles: The subtitle_profiles of this DeviceProfile.  # noqa: E501
        :type: list[SubtitleProfile]
        """

        self._subtitle_profiles = subtitle_profiles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeviceProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class RemoteSearchQueryTrailerInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'search_info': 'TrailerInfo',
        'item_id': 'int',
        'search_provider_name': 'str',
        'providers': 'list[str]',
        'include_disabled_providers': 'bool'
    }

    attribute_map = {
        'search_info': 'SearchInfo',
        'item_id': 'ItemId',
        'search_provider_name': 'SearchProviderName',
        'providers': 'Providers',
        'include_disabled_providers': 'IncludeDisabledProviders'
    }

    def __init__(self, search_info=None, item_id=None, search_provider_name=None, providers=None, include_disabled_providers=None):  # noqa: E501
        """RemoteSearchQueryTrailerInfo - a model defined in Swagger"""  # noqa: E501
        self._search_info = None
        self._item_id = None
        self._search_provider_name = None
        self._providers = None
        self._include_disabled_providers = None
        self.discriminator = None
        if search_info is not None:
            self.search_info = search_info
        if item_id is not None:
            self.item_id = item_id
        if search_provider_name is not None:
            self.search_provider_name = search_provider_name
        if providers is not None:
            self.providers = providers
        if include_disabled_providers is not None:
            self.include_disabled_providers = include_disabled_providers

    @property
    def search_info(self):
        """Gets the search_info of this RemoteSearchQueryTrailerInfo.  # noqa: E501


        :return: The search_info of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :rtype: TrailerInfo
        """
        return self._search_info

    @search_info.setter
    def search_info(self, search_info):
        """Sets the search_info of this RemoteSearchQueryTrailerInfo.


        :param search_info: The search_info of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :type: TrailerInfo
        """

        self._search_info = search_info

    @property
    def item_id(self):
        """Gets the item_id of this RemoteSearchQueryTrailerInfo.  # noqa: E501


        :return: The item_id of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this RemoteSearchQueryTrailerInfo.


        :param item_id: The item_id of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def search_provider_name(self):
        """Gets the search_provider_name of this RemoteSearchQueryTrailerInfo.  # noqa: E501


        :return: The search_provider_name of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :rtype: str
        """
        return self._search_provider_name

    @search_provider_name.setter
    def search_provider_name(self, search_provider_name):
        """Sets the search_provider_name of this RemoteSearchQueryTrailerInfo.


        :param search_provider_name: The search_provider_name of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :type: str
        """

        self._search_provider_name = search_provider_name

    @property
    def providers(self):
        """Gets the providers of this RemoteSearchQueryTrailerInfo.  # noqa: E501


        :return: The providers of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._providers

    @providers.setter
    def providers(self, providers):
        """Sets the providers of this RemoteSearchQueryTrailerInfo.


        :param providers: The providers of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :type: list[str]
        """

        self._providers = providers

    @property
    def include_disabled_providers(self):
        """Gets the include_disabled_providers of this RemoteSearchQueryTrailerInfo.  # noqa: E501


        :return: The include_disabled_providers of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._include_disabled_providers

    @include_disabled_providers.setter
    def include_disabled_providers(self, include_disabled_providers):
        """Sets the include_disabled_providers of this RemoteSearchQueryTrailerInfo.


        :param include_disabled_providers: The include_disabled_providers of this RemoteSearchQueryTrailerInfo.  # noqa: E501
        :type: bool
        """

        self._include_disabled_providers = include_disabled_providers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RemoteSearchQueryTrailerInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteSearchQueryTrailerInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class DlnaProfilesDeviceIdentification(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'friendly_name': 'str',
        'model_number': 'str',
        'serial_number': 'str',
        'model_name': 'str',
        'model_description': 'str',
        'device_description': 'str',
        'model_url': 'str',
        'manufacturer': 'str',
        'manufacturer_url': 'str',
        'headers': 'list[DlnaProfilesHttpHeaderInfo]'
    }

    attribute_map = {
        'friendly_name': 'FriendlyName',
        'model_number': 'ModelNumber',
        'serial_number': 'SerialNumber',
        'model_name': 'ModelName',
        'model_description': 'ModelDescription',
        'device_description': 'DeviceDescription',
        'model_url': 'ModelUrl',
        'manufacturer': 'Manufacturer',
        'manufacturer_url': 'ManufacturerUrl',
        'headers': 'Headers'
    }

    def __init__(self, friendly_name=None, model_number=None, serial_number=None, model_name=None, model_description=None, device_description=None, model_url=None, manufacturer=None, manufacturer_url=None, headers=None):  # noqa: E501
        """DlnaProfilesDeviceIdentification - a model defined in Swagger"""  # noqa: E501
        self._friendly_name = None
        self._model_number = None
        self._serial_number = None
        self._model_name = None
        self._model_description = None
        self._device_description = None
        self._model_url = None
        self._manufacturer = None
        self._manufacturer_url = None
        self._headers = None
        self.discriminator = None
        if friendly_name is not None:
            self.friendly_name = friendly_name
        if model_number is not None:
            self.model_number = model_number
        if serial_number is not None:
            self.serial_number = serial_number
        if model_name is not None:
            self.model_name = model_name
        if model_description is not None:
            self.model_description = model_description
        if device_description is not None:
            self.device_description = device_description
        if model_url is not None:
            self.model_url = model_url
        if manufacturer is not None:
            self.manufacturer = manufacturer
        if manufacturer_url is not None:
            self.manufacturer_url = manufacturer_url
        if headers is not None:
            self.headers = headers

    @property
    def friendly_name(self):
        """Gets the friendly_name of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The friendly_name of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        """Sets the friendly_name of this DlnaProfilesDeviceIdentification.


        :param friendly_name: The friendly_name of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._friendly_name = friendly_name

    @property
    def model_number(self):
        """Gets the model_number of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The model_number of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._model_number

    @model_number.setter
    def model_number(self, model_number):
        """Sets the model_number of this DlnaProfilesDeviceIdentification.


        :param model_number: The model_number of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._model_number = model_number

    @property
    def serial_number(self):
        """Gets the serial_number of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The serial_number of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this DlnaProfilesDeviceIdentification.


        :param serial_number: The serial_number of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def model_name(self):
        """Gets the model_name of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The model_name of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this DlnaProfilesDeviceIdentification.


        :param model_name: The model_name of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def model_description(self):
        """Gets the model_description of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The model_description of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._model_description

    @model_description.setter
    def model_description(self, model_description):
        """Sets the model_description of this DlnaProfilesDeviceIdentification.


        :param model_description: The model_description of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._model_description = model_description

    @property
    def device_description(self):
        """Gets the device_description of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The device_description of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._device_description

    @device_description.setter
    def device_description(self, device_description):
        """Sets the device_description of this DlnaProfilesDeviceIdentification.


        :param device_description: The device_description of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._device_description = device_description

    @property
    def model_url(self):
        """Gets the model_url of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The model_url of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._model_url

    @model_url.setter
    def model_url(self, model_url):
        """Sets the model_url of this DlnaProfilesDeviceIdentification.


        :param model_url: The model_url of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._model_url = model_url

    @property
    def manufacturer(self):
        """Gets the manufacturer of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The manufacturer of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, manufacturer):
        """Sets the manufacturer of this DlnaProfilesDeviceIdentification.


        :param manufacturer: The manufacturer of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._manufacturer = manufacturer

    @property
    def manufacturer_url(self):
        """Gets the manufacturer_url of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The manufacturer_url of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer_url

    @manufacturer_url.setter
    def manufacturer_url(self, manufacturer_url):
        """Sets the manufacturer_url of this DlnaProfilesDeviceIdentification.


        :param manufacturer_url: The manufacturer_url of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: str
        """

        self._manufacturer_url = manufacturer_url

    @property
    def headers(self):
        """Gets the headers of this DlnaProfilesDeviceIdentification.  # noqa: E501


        :return: The headers of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :rtype: list[DlnaProfilesHttpHeaderInfo]
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this DlnaProfilesDeviceIdentification.


        :param headers: The headers of this DlnaProfilesDeviceIdentification.  # noqa: E501
        :type: list[DlnaProfilesHttpHeaderInfo]
        """

        self._headers = headers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DlnaProfilesDeviceIdentification, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DlnaProfilesDeviceIdentification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class DevicesContentUploadHistory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'device_id': 'str',
        'files_uploaded': 'list[DevicesLocalFileInfo]'
    }

    attribute_map = {
        'device_id': 'DeviceId',
        'files_uploaded': 'FilesUploaded'
    }

    def __init__(self, device_id=None, files_uploaded=None):  # noqa: E501
        """DevicesContentUploadHistory - a model defined in Swagger"""  # noqa: E501
        self._device_id = None
        self._files_uploaded = None
        self.discriminator = None
        if device_id is not None:
            self.device_id = device_id
        if files_uploaded is not None:
            self.files_uploaded = files_uploaded

    @property
    def device_id(self):
        """Gets the device_id of this DevicesContentUploadHistory.  # noqa: E501


        :return: The device_id of this DevicesContentUploadHistory.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this DevicesContentUploadHistory.


        :param device_id: The device_id of this DevicesContentUploadHistory.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def files_uploaded(self):
        """Gets the files_uploaded of this DevicesContentUploadHistory.  # noqa: E501


        :return: The files_uploaded of this DevicesContentUploadHistory.  # noqa: E501
        :rtype: list[DevicesLocalFileInfo]
        """
        return self._files_uploaded

    @files_uploaded.setter
    def files_uploaded(self, files_uploaded):
        """Sets the files_uploaded of this DevicesContentUploadHistory.


        :param files_uploaded: The files_uploaded of this DevicesContentUploadHistory.  # noqa: E501
        :type: list[DevicesLocalFileInfo]
        """

        self._files_uploaded = files_uploaded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicesContentUploadHistory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicesContentUploadHistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ApiBaseItemsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is4_k': 'bool',
        'enable_total_record_count': 'bool',
        'recording_keyword': 'str',
        'recording_keyword_type': 'LiveTvKeywordType',
        'random_seed': 'int',
        'genre_ids': 'str',
        'collection_ids': 'str',
        'tag_ids': 'str',
        'exclude_tag_ids': 'str',
        'exclude_artist_ids': 'str',
        'album_artist_ids': 'str',
        'contributing_artist_ids': 'str',
        'album_ids': 'str',
        'outer_ids': 'str',
        'list_item_ids': 'str',
        'audio_languages': 'str',
        'subtitle_languages': 'str',
        'can_edit_items': 'bool',
        'group_items_into': 'LibraryItemLinkType',
        'min_width': 'int',
        'min_height': 'int',
        'max_width': 'int',
        'max_height': 'int',
        'group_programs_by_series': 'bool',
        'air_days': 'list[DayOfWeek]',
        'is_airing': 'bool',
        'has_aired': 'bool'
    }

    attribute_map = {
        'is4_k': 'Is4K',
        'enable_total_record_count': 'EnableTotalRecordCount',
        'recording_keyword': 'RecordingKeyword',
        'recording_keyword_type': 'RecordingKeywordType',
        'random_seed': 'RandomSeed',
        'genre_ids': 'GenreIds',
        'collection_ids': 'CollectionIds',
        'tag_ids': 'TagIds',
        'exclude_tag_ids': 'ExcludeTagIds',
        'exclude_artist_ids': 'ExcludeArtistIds',
        'album_artist_ids': 'AlbumArtistIds',
        'contributing_artist_ids': 'ContributingArtistIds',
        'album_ids': 'AlbumIds',
        'outer_ids': 'OuterIds',
        'list_item_ids': 'ListItemIds',
        'audio_languages': 'AudioLanguages',
        'subtitle_languages': 'SubtitleLanguages',
        'can_edit_items': 'CanEditItems',
        'group_items_into': 'GroupItemsInto',
        'min_width': 'MinWidth',
        'min_height': 'MinHeight',
        'max_width': 'MaxWidth',
        'max_height': 'MaxHeight',
        'group_programs_by_series': 'GroupProgramsBySeries',
        'air_days': 'AirDays',
        'is_airing': 'IsAiring',
        'has_aired': 'HasAired'
    }

    def __init__(self, is4_k=None, enable_total_record_count=None, recording_keyword=None, recording_keyword_type=None, random_seed=None, genre_ids=None, collection_ids=None, tag_ids=None, exclude_tag_ids=None, exclude_artist_ids=None, album_artist_ids=None, contributing_artist_ids=None, album_ids=None, outer_ids=None, list_item_ids=None, audio_languages=None, subtitle_languages=None, can_edit_items=None, group_items_into=None, min_width=None, min_height=None, max_width=None, max_height=None, group_programs_by_series=None, air_days=None, is_airing=None, has_aired=None):  # noqa: E501
        """ApiBaseItemsRequest - a model defined in Swagger"""  # noqa: E501
        self._is4_k = None
        self._enable_total_record_count = None
        self._recording_keyword = None
        self._recording_keyword_type = None
        self._random_seed = None
        self._genre_ids = None
        self._collection_ids = None
        self._tag_ids = None
        self._exclude_tag_ids = None
        self._exclude_artist_ids = None
        self._album_artist_ids = None
        self._contributing_artist_ids = None
        self._album_ids = None
        self._outer_ids = None
        self._list_item_ids = None
        self._audio_languages = None
        self._subtitle_languages = None
        self._can_edit_items = None
        self._group_items_into = None
        self._min_width = None
        self._min_height = None
        self._max_width = None
        self._max_height = None
        self._group_programs_by_series = None
        self._air_days = None
        self._is_airing = None
        self._has_aired = None
        self.discriminator = None
        if is4_k is not None:
            self.is4_k = is4_k
        if enable_total_record_count is not None:
            self.enable_total_record_count = enable_total_record_count
        if recording_keyword is not None:
            self.recording_keyword = recording_keyword
        if recording_keyword_type is not None:
            self.recording_keyword_type = recording_keyword_type
        if random_seed is not None:
            self.random_seed = random_seed
        if genre_ids is not None:
            self.genre_ids = genre_ids
        if collection_ids is not None:
            self.collection_ids = collection_ids
        if tag_ids is not None:
            self.tag_ids = tag_ids
        if exclude_tag_ids is not None:
            self.exclude_tag_ids = exclude_tag_ids
        if exclude_artist_ids is not None:
            self.exclude_artist_ids = exclude_artist_ids
        if album_artist_ids is not None:
            self.album_artist_ids = album_artist_ids
        if contributing_artist_ids is not None:
            self.contributing_artist_ids = contributing_artist_ids
        if album_ids is not None:
            self.album_ids = album_ids
        if outer_ids is not None:
            self.outer_ids = outer_ids
        if list_item_ids is not None:
            self.list_item_ids = list_item_ids
        if audio_languages is not None:
            self.audio_languages = audio_languages
        if subtitle_languages is not None:
            self.subtitle_languages = subtitle_languages
        if can_edit_items is not None:
            self.can_edit_items = can_edit_items
        if group_items_into is not None:
            self.group_items_into = group_items_into
        if min_width is not None:
            self.min_width = min_width
        if min_height is not None:
            self.min_height = min_height
        if max_width is not None:
            self.max_width = max_width
        if max_height is not None:
            self.max_height = max_height
        if group_programs_by_series is not None:
            self.group_programs_by_series = group_programs_by_series
        if air_days is not None:
            self.air_days = air_days
        if is_airing is not None:
            self.is_airing = is_airing
        if has_aired is not None:
            self.has_aired = has_aired

    @property
    def is4_k(self):
        """Gets the is4_k of this ApiBaseItemsRequest.  # noqa: E501


        :return: The is4_k of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is4_k

    @is4_k.setter
    def is4_k(self, is4_k):
        """Sets the is4_k of this ApiBaseItemsRequest.


        :param is4_k: The is4_k of this ApiBaseItemsRequest.  # noqa: E501
        :type: bool
        """

        self._is4_k = is4_k

    @property
    def enable_total_record_count(self):
        """Gets the enable_total_record_count of this ApiBaseItemsRequest.  # noqa: E501


        :return: The enable_total_record_count of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_total_record_count

    @enable_total_record_count.setter
    def enable_total_record_count(self, enable_total_record_count):
        """Sets the enable_total_record_count of this ApiBaseItemsRequest.


        :param enable_total_record_count: The enable_total_record_count of this ApiBaseItemsRequest.  # noqa: E501
        :type: bool
        """

        self._enable_total_record_count = enable_total_record_count

    @property
    def recording_keyword(self):
        """Gets the recording_keyword of this ApiBaseItemsRequest.  # noqa: E501


        :return: The recording_keyword of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._recording_keyword

    @recording_keyword.setter
    def recording_keyword(self, recording_keyword):
        """Sets the recording_keyword of this ApiBaseItemsRequest.


        :param recording_keyword: The recording_keyword of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._recording_keyword = recording_keyword

    @property
    def recording_keyword_type(self):
        """Gets the recording_keyword_type of this ApiBaseItemsRequest.  # noqa: E501


        :return: The recording_keyword_type of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: LiveTvKeywordType
        """
        return self._recording_keyword_type

    @recording_keyword_type.setter
    def recording_keyword_type(self, recording_keyword_type):
        """Sets the recording_keyword_type of this ApiBaseItemsRequest.


        :param recording_keyword_type: The recording_keyword_type of this ApiBaseItemsRequest.  # noqa: E501
        :type: LiveTvKeywordType
        """

        self._recording_keyword_type = recording_keyword_type

    @property
    def random_seed(self):
        """Gets the random_seed of this ApiBaseItemsRequest.  # noqa: E501


        :return: The random_seed of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: int
        """
        return self._random_seed

    @random_seed.setter
    def random_seed(self, random_seed):
        """Sets the random_seed of this ApiBaseItemsRequest.


        :param random_seed: The random_seed of this ApiBaseItemsRequest.  # noqa: E501
        :type: int
        """

        self._random_seed = random_seed

    @property
    def genre_ids(self):
        """Gets the genre_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The genre_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._genre_ids

    @genre_ids.setter
    def genre_ids(self, genre_ids):
        """Sets the genre_ids of this ApiBaseItemsRequest.


        :param genre_ids: The genre_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._genre_ids = genre_ids

    @property
    def collection_ids(self):
        """Gets the collection_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The collection_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._collection_ids

    @collection_ids.setter
    def collection_ids(self, collection_ids):
        """Sets the collection_ids of this ApiBaseItemsRequest.


        :param collection_ids: The collection_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._collection_ids = collection_ids

    @property
    def tag_ids(self):
        """Gets the tag_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The tag_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._tag_ids

    @tag_ids.setter
    def tag_ids(self, tag_ids):
        """Sets the tag_ids of this ApiBaseItemsRequest.


        :param tag_ids: The tag_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._tag_ids = tag_ids

    @property
    def exclude_tag_ids(self):
        """Gets the exclude_tag_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The exclude_tag_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._exclude_tag_ids

    @exclude_tag_ids.setter
    def exclude_tag_ids(self, exclude_tag_ids):
        """Sets the exclude_tag_ids of this ApiBaseItemsRequest.


        :param exclude_tag_ids: The exclude_tag_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._exclude_tag_ids = exclude_tag_ids

    @property
    def exclude_artist_ids(self):
        """Gets the exclude_artist_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The exclude_artist_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._exclude_artist_ids

    @exclude_artist_ids.setter
    def exclude_artist_ids(self, exclude_artist_ids):
        """Sets the exclude_artist_ids of this ApiBaseItemsRequest.


        :param exclude_artist_ids: The exclude_artist_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._exclude_artist_ids = exclude_artist_ids

    @property
    def album_artist_ids(self):
        """Gets the album_artist_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The album_artist_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._album_artist_ids

    @album_artist_ids.setter
    def album_artist_ids(self, album_artist_ids):
        """Sets the album_artist_ids of this ApiBaseItemsRequest.


        :param album_artist_ids: The album_artist_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._album_artist_ids = album_artist_ids

    @property
    def contributing_artist_ids(self):
        """Gets the contributing_artist_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The contributing_artist_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._contributing_artist_ids

    @contributing_artist_ids.setter
    def contributing_artist_ids(self, contributing_artist_ids):
        """Sets the contributing_artist_ids of this ApiBaseItemsRequest.


        :param contributing_artist_ids: The contributing_artist_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._contributing_artist_ids = contributing_artist_ids

    @property
    def album_ids(self):
        """Gets the album_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The album_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._album_ids

    @album_ids.setter
    def album_ids(self, album_ids):
        """Sets the album_ids of this ApiBaseItemsRequest.


        :param album_ids: The album_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._album_ids = album_ids

    @property
    def outer_ids(self):
        """Gets the outer_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The outer_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._outer_ids

    @outer_ids.setter
    def outer_ids(self, outer_ids):
        """Sets the outer_ids of this ApiBaseItemsRequest.


        :param outer_ids: The outer_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._outer_ids = outer_ids

    @property
    def list_item_ids(self):
        """Gets the list_item_ids of this ApiBaseItemsRequest.  # noqa: E501


        :return: The list_item_ids of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._list_item_ids

    @list_item_ids.setter
    def list_item_ids(self, list_item_ids):
        """Sets the list_item_ids of this ApiBaseItemsRequest.


        :param list_item_ids: The list_item_ids of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._list_item_ids = list_item_ids

    @property
    def audio_languages(self):
        """Gets the audio_languages of this ApiBaseItemsRequest.  # noqa: E501


        :return: The audio_languages of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._audio_languages

    @audio_languages.setter
    def audio_languages(self, audio_languages):
        """Sets the audio_languages of this ApiBaseItemsRequest.


        :param audio_languages: The audio_languages of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._audio_languages = audio_languages

    @property
    def subtitle_languages(self):
        """Gets the subtitle_languages of this ApiBaseItemsRequest.  # noqa: E501


        :return: The subtitle_languages of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: str
        """
        return self._subtitle_languages

    @subtitle_languages.setter
    def subtitle_languages(self, subtitle_languages):
        """Sets the subtitle_languages of this ApiBaseItemsRequest.


        :param subtitle_languages: The subtitle_languages of this ApiBaseItemsRequest.  # noqa: E501
        :type: str
        """

        self._subtitle_languages = subtitle_languages

    @property
    def can_edit_items(self):
        """Gets the can_edit_items of this ApiBaseItemsRequest.  # noqa: E501


        :return: The can_edit_items of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit_items

    @can_edit_items.setter
    def can_edit_items(self, can_edit_items):
        """Sets the can_edit_items of this ApiBaseItemsRequest.


        :param can_edit_items: The can_edit_items of this ApiBaseItemsRequest.  # noqa: E501
        :type: bool
        """

        self._can_edit_items = can_edit_items

    @property
    def group_items_into(self):
        """Gets the group_items_into of this ApiBaseItemsRequest.  # noqa: E501


        :return: The group_items_into of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: LibraryItemLinkType
        """
        return self._group_items_into

    @group_items_into.setter
    def group_items_into(self, group_items_into):
        """Sets the group_items_into of this ApiBaseItemsRequest.


        :param group_items_into: The group_items_into of this ApiBaseItemsRequest.  # noqa: E501
        :type: LibraryItemLinkType
        """

        self._group_items_into = group_items_into

    @property
    def min_width(self):
        """Gets the min_width of this ApiBaseItemsRequest.  # noqa: E501


        :return: The min_width of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: int
        """
        return self._min_width

    @min_width.setter
    def min_width(self, min_width):
        """Sets the min_width of this ApiBaseItemsRequest.


        :param min_width: The min_width of this ApiBaseItemsRequest.  # noqa: E501
        :type: int
        """

        self._min_width = min_width

    @property
    def min_height(self):
        """Gets the min_height of this ApiBaseItemsRequest.  # noqa: E501


        :return: The min_height of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: int
        """
        return self._min_height

    @min_height.setter
    def min_height(self, min_height):
        """Sets the min_height of this ApiBaseItemsRequest.


        :param min_height: The min_height of this ApiBaseItemsRequest.  # noqa: E501
        :type: int
        """

        self._min_height = min_height

    @property
    def max_width(self):
        """Gets the max_width of this ApiBaseItemsRequest.  # noqa: E501


        :return: The max_width of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_width

    @max_width.setter
    def max_width(self, max_width):
        """Sets the max_width of this ApiBaseItemsRequest.


        :param max_width: The max_width of this ApiBaseItemsRequest.  # noqa: E501
        :type: int
        """

        self._max_width = max_width

    @property
    def max_height(self):
        """Gets the max_height of this ApiBaseItemsRequest.  # noqa: E501


        :return: The max_height of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_height

    @max_height.setter
    def max_height(self, max_height):
        """Sets the max_height of this ApiBaseItemsRequest.


        :param max_height: The max_height of this ApiBaseItemsRequest.  # noqa: E501
        :type: int
        """

        self._max_height = max_height

    @property
    def group_programs_by_series(self):
        """Gets the group_programs_by_series of this ApiBaseItemsRequest.  # noqa: E501


        :return: The group_programs_by_series of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._group_programs_by_series

    @group_programs_by_series.setter
    def group_programs_by_series(self, group_programs_by_series):
        """Sets the group_programs_by_series of this ApiBaseItemsRequest.


        :param group_programs_by_series: The group_programs_by_series of this ApiBaseItemsRequest.  # noqa: E501
        :type: bool
        """

        self._group_programs_by_series = group_programs_by_series

    @property
    def air_days(self):
        """Gets the air_days of this ApiBaseItemsRequest.  # noqa: E501


        :return: The air_days of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: list[DayOfWeek]
        """
        return self._air_days

    @air_days.setter
    def air_days(self, air_days):
        """Sets the air_days of this ApiBaseItemsRequest.


        :param air_days: The air_days of this ApiBaseItemsRequest.  # noqa: E501
        :type: list[DayOfWeek]
        """

        self._air_days = air_days

    @property
    def is_airing(self):
        """Gets the is_airing of this ApiBaseItemsRequest.  # noqa: E501


        :return: The is_airing of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_airing

    @is_airing.setter
    def is_airing(self, is_airing):
        """Sets the is_airing of this ApiBaseItemsRequest.


        :param is_airing: The is_airing of this ApiBaseItemsRequest.  # noqa: E501
        :type: bool
        """

        self._is_airing = is_airing

    @property
    def has_aired(self):
        """Gets the has_aired of this ApiBaseItemsRequest.  # noqa: E501


        :return: The has_aired of this ApiBaseItemsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._has_aired

    @has_aired.setter
    def has_aired(self, has_aired):
        """Sets the has_aired of this ApiBaseItemsRequest.


        :param has_aired: The has_aired of this ApiBaseItemsRequest.  # noqa: E501
        :type: bool
        """

        self._has_aired = has_aired

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiBaseItemsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiBaseItemsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UITabPageInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page_id': 'str',
        'display_name': 'str',
        'plugin_id': 'str',
        'href': 'str',
        'nav_key': 'str',
        'index': 'int'
    }

    attribute_map = {
        'page_id': 'PageId',
        'display_name': 'DisplayName',
        'plugin_id': 'PluginId',
        'href': 'Href',
        'nav_key': 'NavKey',
        'index': 'Index'
    }

    def __init__(self, page_id=None, display_name=None, plugin_id=None, href=None, nav_key=None, index=None):  # noqa: E501
        """UITabPageInfo - a model defined in Swagger"""  # noqa: E501
        self._page_id = None
        self._display_name = None
        self._plugin_id = None
        self._href = None
        self._nav_key = None
        self._index = None
        self.discriminator = None
        if page_id is not None:
            self.page_id = page_id
        if display_name is not None:
            self.display_name = display_name
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if href is not None:
            self.href = href
        if nav_key is not None:
            self.nav_key = nav_key
        if index is not None:
            self.index = index

    @property
    def page_id(self):
        """Gets the page_id of this UITabPageInfo.  # noqa: E501


        :return: The page_id of this UITabPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this UITabPageInfo.


        :param page_id: The page_id of this UITabPageInfo.  # noqa: E501
        :type: str
        """

        self._page_id = page_id

    @property
    def display_name(self):
        """Gets the display_name of this UITabPageInfo.  # noqa: E501


        :return: The display_name of this UITabPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this UITabPageInfo.


        :param display_name: The display_name of this UITabPageInfo.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def plugin_id(self):
        """Gets the plugin_id of this UITabPageInfo.  # noqa: E501


        :return: The plugin_id of this UITabPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this UITabPageInfo.


        :param plugin_id: The plugin_id of this UITabPageInfo.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def href(self):
        """Gets the href of this UITabPageInfo.  # noqa: E501


        :return: The href of this UITabPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this UITabPageInfo.


        :param href: The href of this UITabPageInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def nav_key(self):
        """Gets the nav_key of this UITabPageInfo.  # noqa: E501


        :return: The nav_key of this UITabPageInfo.  # noqa: E501
        :rtype: str
        """
        return self._nav_key

    @nav_key.setter
    def nav_key(self, nav_key):
        """Sets the nav_key of this UITabPageInfo.


        :param nav_key: The nav_key of this UITabPageInfo.  # noqa: E501
        :type: str
        """

        self._nav_key = nav_key

    @property
    def index(self):
        """Gets the index of this UITabPageInfo.  # noqa: E501


        :return: The index of this UITabPageInfo.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this UITabPageInfo.


        :param index: The index of this UITabPageInfo.  # noqa: E501
        :type: int
        """

        self._index = index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UITabPageInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UITabPageInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
